pub struct Address {
    pub name: String,
    pub address_line1: String,
    pub address_line2: Option<String>,
    pub address_line3: Option<String>,
    pub state_or_region: String,
    pub city: String,
    pub country_code: String,
    pub postal_code: String,
    pub email: Option<String>,
    pub copy_emails: Option<Vec<String>>,
    pub phone_number: Option<String>,
}
Address : The address.

Fields

name: String

The name of the person, business or institution at that address.

address_line1: String

First line of that address.

address_line2: Option<String>

Additional address information, if required.

address_line3: Option<String>

Additional address information, if required.

state_or_region: String

The state or region where the person, business or institution is located.

city: String

The city where the person, business or institution is located.

country_code: String

The two digit country code. In ISO 3166-1 alpha-2 format.

postal_code: String

The postal code of that address. It contains a series of letters or digits or both, sometimes including spaces or punctuation.

email: Option<String>

The email address of the contact associated with the address.

copy_emails: Option<Vec<String>>

The email cc addresses of the contact associated with the address.

phone_number: Option<String>

The phone number of the person, business or institution located at that address.

Implementations

The address.